@@ -20,11 +20,13 @@ DYNAMIC_LINK_URL_BASE_COMPONENT = getattr(
     'OneTimeLink'
 )
 
+DYNAMIC_LINK_URL = ''
+
 if settings.FORCE_SCRIPT_NAME:
-	DYNAMIC_LINK_URL_BASE_COMPONENT = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
+	DYNAMIC_LINK_URL = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
 else:
-	DYNAMIC_LINK_URL_BASE_COMPONENT = '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
-DYNAMIC_LINK_URL_BASE_COMPONENT = DYNAMIC_LINK_URL_BASE_COMPONENT.replace('//', '/')
+	DYNAMIC_LINK_URL = '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
+DYNAMIC_LINK_URL = DYNAMIC_LINK_URL_BASE_COMPONENT.replace('//', '/')
 
 # Uploaded files base directory
 DYNAMIC_LINK_UPLOAD_TO = getattr(
